<?php
/**
 * Main plugin class
 */
class Keyword_Research_Tool {
    /**
     * Initialize the plugin
     */
    public function init() {
        // Add menu page
        add_action('admin_menu', array($this, 'add_admin_menu'));
        
        // Register scripts and styles
        add_action('admin_enqueue_scripts', array($this, 'register_scripts'));
        
        // Register AJAX handlers
        add_action('wp_ajax_krt_search_keywords', array($this, 'ajax_search_keywords'));
        add_action('wp_ajax_nopriv_krt_search_keywords', array($this, 'ajax_search_keywords'));
        
        // Add shortcode for frontend
        add_shortcode('keyword_research_tool', array($this, 'shortcode_output'));
    }
    
    /**
     * Add admin menu
     */
    public function add_admin_menu() {
        add_menu_page(
            __('Keyword Research Tool', 'keyword-research-tool'),
            __('Keyword Research', 'keyword-research-tool'),
            'edit_posts',
            'keyword-research-tool',
            array($this, 'admin_page'),
            'dashicons-search',
            30
        );
    }
    
    /**
     * Register scripts and styles
     */
    public function register_scripts($hook) {
        // Only load on our plugin page or when shortcode is used
        if ($hook != 'toplevel_page_keyword-research-tool' && !is_a($GLOBALS['wp_query']->post, 'WP_Post')) {
            return;
        }
        
        wp_enqueue_style(
            'krt-styles',
            KRT_PLUGIN_URL . 'assets/css/keyword-research-tool.css',
            array(),
            KRT_VERSION
        );
        
        wp_enqueue_script(
            'krt-scripts',
            KRT_PLUGIN_URL . 'assets/js/keyword-research-tool.js',
            array('jquery'),
            KRT_VERSION,
            true
        );
        
        wp_localize_script(
            'krt-scripts',
            'krtData',
            array(
                'ajaxurl' => admin_url('admin-ajax.php'),
                'nonce' => wp_create_nonce('krt_nonce'),
            )
        );
    }
    
    /**
     * Admin page output
     */
    public function admin_page() {
        include KRT_PLUGIN_DIR . 'templates/admin-page.php';
    }
    
    /**
     * Shortcode output
     */
    public function shortcode_output($atts) {
        // Enqueue scripts and styles
        wp_enqueue_style('krt-styles');
        wp_enqueue_script('krt-scripts');
        
        ob_start();
        include KRT_PLUGIN_DIR . 'templates/frontend-tool.php';
        return ob_get_clean();
    }
    
    /**
     * AJAX handler for keyword search
     */
    public function ajax_search_keywords() {
        // Check nonce
        if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'krt_nonce')) {
            wp_send_json_error('Invalid nonce');
        }
        
        // Get search term
        $search_term = isset($_POST['search_term']) ? sanitize_text_field($_POST['search_term']) : '';
        
        if (empty($search_term)) {
            wp_send_json_error('Please enter a search term');
        }
        
        // Get keywords
        $api = new Keyword_API();
        $keywords = $api->get_keywords($search_term);
        
        wp_send_json_success($keywords);
    }
}